import { Component, OnInit, Input, Output } from "@angular/core";
import { SessionCartService } from "./session-cart.service";
import { Session } from "src/app/models/Session";

@Component({
    selector: "app-session-cart",
    templateUrl: "./session-cart.component.html",
    styleUrls: ["./session-cart.component.scss"]
})
export class SessionCartComponent implements OnInit {

    @Input()
    public readableEventId: string;
    public isOpen: boolean;
    public sessionCart: Array<Session>;

    constructor(private sessionCartService: SessionCartService) {}

    ngOnInit() {
        this.isOpen = this.sessionCartService.isOpen;
        this.sessionCartService.isOpenChange.subscribe(isOpen => {
            this.isOpen = isOpen;
        });

        this.sessionCart = this.sessionCartService.getSessionCartForEvent(this.readableEventId);
        this.sessionCartService.sessionCartChange.subscribe(sessionCart => {
          this.sessionCart = sessionCart;
        });
    }

    public collapse() {
        this.sessionCartService.isOpen = false;
    }

    public removeSessionFromCart(session: Session) {
        this.sessionCartService.removeSession(this.readableEventId, session);
    }

    public sessionCartCount(): number {
        return this.sessionCart.length;
    }
}
