import { Component, OnInit, Input } from "@angular/core";
import { SessionCartService } from "../../event/session-cart/session-cart.service";
import { Session } from "src/app/models/Session";
import { Event } from "src/app/models/Event";
import { ActiveEventService } from "src/app/services/active-event.service";

@Component({
    selector: "app-session-selection",
    templateUrl: "./session-selection.component.html",
    styleUrls: ["./session-selection.component.scss"]
})
export class SessionSelectionComponent implements OnInit {
    @Input()
    public readableEventId: string;

    public isSessionCartEnabled: boolean;
    public sessionCart: Array<Session>;
    public event: Event;
    public cntActiveAttendeeRegistrations = 0;

    constructor(private activeEventService: ActiveEventService, private sessionCartService: SessionCartService) {}

    ngOnInit() {
        this.subscribeToSessionCartChange();
        this.subscribeToCntActiveAttendeeRegistrations();

        this.activeEventService.getEvent(this.readableEventId).subscribe(event => {
            this.event = event;
            this.setIsSessionCartAllowed();
        });
    }

    public removeSessionFromCart(session: Session) {
        this.sessionCartService.removeSession(this.readableEventId, session);
    }

    private subscribeToSessionCartChange() {
        this.sessionCart = this.sessionCartService.getSessionCartForEvent(this.readableEventId);
        this.sessionCartService.sessionCartChange.subscribe(sessionCart => {
            this.sessionCart = sessionCart;
        });
    }

    private subscribeToCntActiveAttendeeRegistrations() {
        this.cntActiveAttendeeRegistrations = this.sessionCartService.getCntActiveAttendeeRegistrations(this.readableEventId);
        this.sessionCartService.cntActiveAttendeeRegistrationsChange.subscribe(count => {
            this.cntActiveAttendeeRegistrations = count;
        });
    }

    private async setIsSessionCartAllowed() {
        const hasEventSessions = await this.activeEventService.hasEventSessions(this.readableEventId);
        const isFreeEvent = await this.activeEventService.isFreeEvent(this.readableEventId);

        this.isSessionCartEnabled = this.sessionCartService.isSessionCartEnabledForEvent(
            this.event,
            isFreeEvent,
            hasEventSessions
        );
    }
}
